@@ -7,8 +7,9 @@ from databroker.v2 import Broker
 from event_model import RunRouter
 from ophyd.sim import NumpySeqHandler
 
+import pdfstream.io as io
 from pdfstream.callbacks.analysis import AnalysisConfig, VisConfig, ExportConfig, AnalysisStream, Exporter, \
-    Visualizer, no_need_to_refresh_db
+    Visualizer, no_need_to_refresh_db, ExporterXpdan
 from pdfstream.callbacks.calibration import CalibrationConfig, Calibration
 from pdfstream.servers import CONFIG_DIR, ServerNames
 from pdfstream.servers.base import ServerConfig, find_cfg_file, BaseServer, StartStopCallback
@@ -62,6 +63,7 @@ class XPDConfig(AnalysisConfig, VisConfig, ExportConfig, CalibrationConfig):
             "export_files": self.getboolean("FUNCTIONALITY", "export_files"),
             "visualize_data": self.getboolean("FUNCTIONALITY", "visualize_data"),
             "send_messages": self.getboolean("FUNCTIONALITY", "send_messages"),
+            "export_files_in_xpdan_style": self.getboolean("FUNCTIONALITY", "export_files_in_xpdan_style")
         }
 
 
@@ -124,31 +126,32 @@ class XPDFactory:
 
     def __init__(self, config: XPDConfig):
         self.config = config
-        self.analysis = AnalysisStream(config)
-        self.func = self.config.functionality
-        if self.func["do_calibration"]:
-            self.calibration = Calibration(config)
-        if self.func["dump_to_db"]:
-            self.analysis.subscribe(self.config.an_db.v1.insert)
-        if self.func["export_files"]:
-            self.analysis.subscribe(Exporter(config))
-        if self.func["visualize_data"]:
-            self.analysis.subscribe(Visualizer(config))
-        if self.func["send_messages"]:
-            self.analysis.subscribe(Publisher(**self.config.publisher_config))
+        self.functionality = self.config.functionality
+        self.analysis = [AnalysisStream(config)]
+        self.calibration = [Calibration(config)] if self.functionality["do_calibration"] else []
+        if self.functionality["dump_to_db"]:
+            self.analysis[0].subscribe(self.config.an_db.v1.insert)
+        if self.functionality["export_files"]:
+            self.analysis[0].subscribe(Exporter(config))
+        if self.functionality["visualize_data"]:
+            self.analysis[0].subscribe(Visualizer(config))
+        if self.functionality["send_messages"]:
+            self.analysis[0].subscribe(Publisher(**self.config.publisher_config))
+        if self.functionality["export_files_in_xpdan_style"]:
+            self.analysis[0].subscribe(ExporterXpdan(config))
 
     def __call__(self, name: str, doc: dict) -> tp.Tuple[list, list]:
         if name == "start":
             if doc.get(self.config.dark_identifier):
                 # dark frame run
+                io.server_message("Ignore dark frame.")
                 return [], []
             elif doc.get(self.config.calib_identifier):
                 # calibration run
-                if self.func.do_calibration:
-                    return [self.calibration], []
-                else:
-                    return [], []
+                io.server_message("Start calibration.")
+                return self.calibration, []
             else:
                 # light frame run
-                return [self.analysis], []
+                io.server_message("Start data reduction.")
+                return self.analysis, []
         return [], []
